Module: Aws::IdentityStore

Defined in:
lib/aws-sdk-identitystore/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/params.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-identitystore/plugins/endpoints.rb,
lib/aws-sdk-identitystore/endpoint_provider.rb,
lib/aws-sdk-identitystore/client_api.rb,
lib/aws-sdk-identitystore/endpoints.rb,
lib/aws-sdk-identitystore/resource.rb,
lib/aws-sdk-identitystore/errors.rb,
lib/aws-sdk-identitystore/client.rb,
lib/aws-sdk-identitystore/types.rb,
lib/aws-sdk-identitystore.rb

Overview

This module provides support for AWS SSO Identity Store. This module is available in the aws-sdk-identitystore gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

identity_store = Aws::IdentityStore::Client.new
resp = identity_store.create_group(params)

See Client for more information.

Errors

Errors returned from AWS SSO Identity Store are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::IdentityStore::Errors::ServiceError
  # rescues all AWS SSO Identity Store API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Params, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.72.0'