Class: Aws::IdentityStore::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IdentityStore::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-identitystore/client.rb,
sig/client.rbs
Overview
An API client for IdentityStore. To construct a client, you need to configure a :region and :credentials.
client = Aws::IdentityStore::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateGroupMembershipResponseSuccess, _CreateGroupResponseSuccess, _CreateUserResponseSuccess, _DeleteGroupMembershipResponseSuccess, _DeleteGroupResponseSuccess, _DeleteUserResponseSuccess, _DescribeGroupMembershipResponseSuccess, _DescribeGroupResponseSuccess, _DescribeUserResponseSuccess, _GetGroupIdResponseSuccess, _GetGroupMembershipIdResponseSuccess, _GetUserIdResponseSuccess, _IsMemberInGroupsResponseSuccess, _ListGroupMembershipsForMemberResponseSuccess, _ListGroupMembershipsResponseSuccess, _ListGroupsResponseSuccess, _ListUsersResponseSuccess, _UpdateGroupResponseSuccess, _UpdateUserResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_group(params = {}) ⇒ Types::CreateGroupResponse
Creates a group within the specified identity store.
-
#create_group_membership(params = {}) ⇒ Types::CreateGroupMembershipResponse
Creates a relationship between a member and a group.
-
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user within the specified identity store.
-
#delete_group(params = {}) ⇒ Struct
Delete a group within an identity store given
GroupId. -
#delete_group_membership(params = {}) ⇒ Struct
Delete a membership within a group given
MembershipId. -
#delete_user(params = {}) ⇒ Struct
Deletes a user within an identity store given
UserId. -
#describe_group(params = {}) ⇒ Types::DescribeGroupResponse
Retrieves the group metadata and attributes from
GroupIdin an identity store. -
#describe_group_membership(params = {}) ⇒ Types::DescribeGroupMembershipResponse
Retrieves membership metadata and attributes from
MembershipIdin an identity store. -
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Retrieves the user metadata and attributes from the
UserIdin an identity store. -
#get_group_id(params = {}) ⇒ Types::GetGroupIdResponse
Retrieves
GroupIdin an identity store. -
#get_group_membership_id(params = {}) ⇒ Types::GetGroupMembershipIdResponse
Retrieves the
MembershipIdin an identity store. -
#get_user_id(params = {}) ⇒ Types::GetUserIdResponse
Retrieves the
UserIdin an identity store. -
#is_member_in_groups(params = {}) ⇒ Types::IsMemberInGroupsResponse
Checks the user's membership in all requested groups and returns if the member exists in all queried groups.
-
#list_group_memberships(params = {}) ⇒ Types::ListGroupMembershipsResponse
For the specified group in the specified identity store, returns the list of all
GroupMembershipobjects and returns results in paginated form. -
#list_group_memberships_for_member(params = {}) ⇒ Types::ListGroupMembershipsForMemberResponse
For the specified member in the specified identity store, returns the list of all
GroupMembershipobjects and returns results in paginated form. -
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Lists all groups in the identity store.
-
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists all users in the identity store.
-
#update_group(params = {}) ⇒ Struct
Updates the specified group metadata and attributes in the specified identity store.
-
#update_user(params = {}) ⇒ Struct
Updates the specified user metadata and attributes in the specified identity store.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-identitystore/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1781 1782 1783 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1781 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1784 1785 1786 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1784 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1754 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IdentityStore') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-identitystore' context[:gem_version] = '1.72.0' Seahorse::Client::Request.new(handlers, context) end |
#create_group(params = {}) ⇒ Types::CreateGroupResponse
Creates a group within the specified identity store.
88 |
# File 'sig/client.rbs', line 88
def create_group: (
|
#create_group_membership(params = {}) ⇒ Types::CreateGroupMembershipResponse
Creates a relationship between a member and a group. The following
identifiers must be specified: GroupId, IdentityStoreId, and
MemberId.
101 |
# File 'sig/client.rbs', line 101
def create_group_membership: (
|
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user within the specified identity store.
116 |
# File 'sig/client.rbs', line 116
def create_user: (
|
#delete_group(params = {}) ⇒ Struct
Delete a group within an identity store given GroupId.
186 |
# File 'sig/client.rbs', line 186
def delete_group: (
|
#delete_group_membership(params = {}) ⇒ Struct
Delete a membership within a group given MembershipId.
196 |
# File 'sig/client.rbs', line 196
def delete_group_membership: (
|
#delete_user(params = {}) ⇒ Struct
Deletes a user within an identity store given UserId.
206 |
# File 'sig/client.rbs', line 206
def delete_user: (
|
#describe_group(params = {}) ⇒ Types::DescribeGroupResponse
Retrieves the group metadata and attributes from GroupId in an
identity store.
225 |
# File 'sig/client.rbs', line 225
def describe_group: (
|
#describe_group_membership(params = {}) ⇒ Types::DescribeGroupMembershipResponse
Retrieves membership metadata and attributes from MembershipId in an
identity store.
243 |
# File 'sig/client.rbs', line 243
def describe_group_membership: (
|
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Retrieves the user metadata and attributes from the UserId in an
identity store.
279 |
# File 'sig/client.rbs', line 279
def describe_user: (
|
#get_group_id(params = {}) ⇒ Types::GetGroupIdResponse
Retrieves GroupId in an identity store.
292 |
# File 'sig/client.rbs', line 292
def get_group_id: (
|
#get_group_membership_id(params = {}) ⇒ Types::GetGroupMembershipIdResponse
Retrieves the MembershipId in an identity store.
304 |
# File 'sig/client.rbs', line 304
def get_group_membership_id: (
|
#get_user_id(params = {}) ⇒ Types::GetUserIdResponse
Retrieves the UserId in an identity store.
319 |
# File 'sig/client.rbs', line 319
def get_user_id: (
|
#is_member_in_groups(params = {}) ⇒ Types::IsMemberInGroupsResponse
Checks the user's membership in all requested groups and returns if the member exists in all queried groups.
330 |
# File 'sig/client.rbs', line 330
def is_member_in_groups: (
|
#list_group_memberships(params = {}) ⇒ Types::ListGroupMembershipsResponse
For the specified group in the specified identity store, returns the
list of all GroupMembership objects and returns results in
paginated form.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
345 |
# File 'sig/client.rbs', line 345
def list_group_memberships: (
|
#list_group_memberships_for_member(params = {}) ⇒ Types::ListGroupMembershipsForMemberResponse
For the specified member in the specified identity store, returns the
list of all GroupMembership objects and returns results in
paginated form.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
359 |
# File 'sig/client.rbs', line 359
def list_group_memberships_for_member: (
|
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Lists all groups in the identity store. Returns a paginated list of
complete Group objects. Filtering for a Group by the DisplayName
attribute is deprecated. Instead, use the GetGroupId API action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
375 |
# File 'sig/client.rbs', line 375
def list_groups: (
|
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists all users in the identity store. Returns a paginated list of
complete User objects. Filtering for a User by the UserName
attribute is deprecated. Instead, use the GetUserId API action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
394 |
# File 'sig/client.rbs', line 394
def list_users: (
|
#update_group(params = {}) ⇒ Struct
Updates the specified group metadata and attributes in the specified identity store.
412 |
# File 'sig/client.rbs', line 412
def update_group: (
|
#update_user(params = {}) ⇒ Struct
Updates the specified user metadata and attributes in the specified identity store.
428 |
# File 'sig/client.rbs', line 428
def update_user: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1774 1775 1776 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1774 def waiter_names [] end |