Class: Aws::IdentityStore::Types::Filter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-identitystore/types.rb

Overview

A query filter used by ‘ListUsers` and `ListGroups`. This filter object provides the attribute name and attribute value to search users or groups.

Constant Summary collapse

SENSITIVE =
[:attribute_value]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_pathString

The attribute path that is used to specify which attribute name to search. Length limit is 255 characters. For example, ‘UserName` is a valid attribute path for the ` ListUsers` API, and `DisplayName` is a valid attribute path for the ` ListGroups` API.

Returns:

  • (String)


854
855
856
857
858
859
# File 'lib/aws-sdk-identitystore/types.rb', line 854

class Filter < Struct.new(
  :attribute_path,
  :attribute_value)
  SENSITIVE = [:attribute_value]
  include Aws::Structure
end

#attribute_valueString

Represents the data for an attribute. Each attribute value is described as a name-value pair.

Returns:

  • (String)


854
855
856
857
858
859
# File 'lib/aws-sdk-identitystore/types.rb', line 854

class Filter < Struct.new(
  :attribute_path,
  :attribute_value)
  SENSITIVE = [:attribute_value]
  include Aws::Structure
end