Class: Aws::IdentityStore::Types::ListGroupMembershipsForMemberRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-identitystore/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identity_store_idString

The globally unique identifier for the identity store.

Returns:

  • (String)


1211
1212
1213
1214
1215
1216
1217
1218
# File 'lib/aws-sdk-identitystore/types.rb', line 1211

class ListGroupMembershipsForMemberRequest < Struct.new(
  :identity_store_id,
  :member_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to be returned per request. This parameter is used in the ‘ ListUsers` and `ListGroups` requests to specify how many results to return in one page. The length limit is 50 characters.

Returns:

  • (Integer)


1211
1212
1213
1214
1215
1216
1217
1218
# File 'lib/aws-sdk-identitystore/types.rb', line 1211

class ListGroupMembershipsForMemberRequest < Struct.new(
  :identity_store_id,
  :member_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#member_idTypes::MemberId

An object that contains the identifier of a group member. Setting the ‘UserID` field to the specific identifier for a user indicates that the user is a member of the group.

Returns:



1211
1212
1213
1214
1215
1216
1217
1218
# File 'lib/aws-sdk-identitystore/types.rb', line 1211

class ListGroupMembershipsForMemberRequest < Struct.new(
  :identity_store_id,
  :member_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token used for the ‘ListUsers`, `ListGroups`, and ` ListGroupMemberships` API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page.

Returns:

  • (String)


1211
1212
1213
1214
1215
1216
1217
1218
# File 'lib/aws-sdk-identitystore/types.rb', line 1211

class ListGroupMembershipsForMemberRequest < Struct.new(
  :identity_store_id,
  :member_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end