Class: Aws::IdentityStore::Types::ListGroupMembershipsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-identitystore/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#group_idString

The identifier for a group in the identity store.

Returns:

  • (String)


1268
1269
1270
1271
1272
1273
1274
1275
# File 'lib/aws-sdk-identitystore/types.rb', line 1268

class ListGroupMembershipsRequest < Struct.new(
  :identity_store_id,
  :group_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#identity_store_idString

The globally unique identifier for the identity store.

Returns:

  • (String)


1268
1269
1270
1271
1272
1273
1274
1275
# File 'lib/aws-sdk-identitystore/types.rb', line 1268

class ListGroupMembershipsRequest < Struct.new(
  :identity_store_id,
  :group_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to be returned per request. This parameter is used in all ‘ List` requests to specify how many results to return in one page.

Returns:

  • (Integer)


1268
1269
1270
1271
1272
1273
1274
1275
# File 'lib/aws-sdk-identitystore/types.rb', line 1268

class ListGroupMembershipsRequest < Struct.new(
  :identity_store_id,
  :group_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token used for the ‘ListUsers`, `ListGroups` and ` ListGroupMemberships` API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page.

Returns:

  • (String)


1268
1269
1270
1271
1272
1273
1274
1275
# File 'lib/aws-sdk-identitystore/types.rb', line 1268

class ListGroupMembershipsRequest < Struct.new(
  :identity_store_id,
  :group_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end