Class: Aws::IdentityStore::Types::ListGroupsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-identitystore/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#groupsArray<Types::Group>

A list of ‘Group` objects in the identity store.

Returns:



1352
1353
1354
1355
1356
1357
# File 'lib/aws-sdk-identitystore/types.rb', line 1352

class ListGroupsResponse < Struct.new(
  :groups,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token used for the ‘ListUsers` and `ListGroups` API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page.

Returns:

  • (String)


1352
1353
1354
1355
1356
1357
# File 'lib/aws-sdk-identitystore/types.rb', line 1352

class ListGroupsResponse < Struct.new(
  :groups,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end