Class: Aws::IdentityStore::Types::ListUsersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-identitystore/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#extensionsArray<String>

A collection of extension names indicating what extensions the service should retrieve alongside other user attributes. ‘aws:identitystore:enterprise` is the only supported extension name.

Returns:

  • (Array<String>)


1395
1396
1397
1398
1399
1400
1401
1402
1403
# File 'lib/aws-sdk-identitystore/types.rb', line 1395

class ListUsersRequest < Struct.new(
  :identity_store_id,
  :extensions,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

A list of ‘Filter` objects, which is used in the `ListUsers` and ` ListGroups` requests.

Returns:



1395
1396
1397
1398
1399
1400
1401
1402
1403
# File 'lib/aws-sdk-identitystore/types.rb', line 1395

class ListUsersRequest < Struct.new(
  :identity_store_id,
  :extensions,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#identity_store_idString

The globally unique identifier for the identity store, such as ‘d-1234567890`. In this example, `d-` is a fixed prefix, and `1234567890` is a randomly generated string that contains numbers and lower case letters. This value is generated at the time that a new identity store is created.

Returns:

  • (String)


1395
1396
1397
1398
1399
1400
1401
1402
1403
# File 'lib/aws-sdk-identitystore/types.rb', line 1395

class ListUsersRequest < Struct.new(
  :identity_store_id,
  :extensions,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to be returned per request. This parameter is used in the ‘ ListUsers` and `ListGroups` requests to specify how many results to return in one page. The length limit is 50 characters.

Returns:

  • (Integer)


1395
1396
1397
1398
1399
1400
1401
1402
1403
# File 'lib/aws-sdk-identitystore/types.rb', line 1395

class ListUsersRequest < Struct.new(
  :identity_store_id,
  :extensions,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token used for the ‘ListUsers` and `ListGroups` API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page.

Returns:

  • (String)


1395
1396
1397
1398
1399
1400
1401
1402
1403
# File 'lib/aws-sdk-identitystore/types.rb', line 1395

class ListUsersRequest < Struct.new(
  :identity_store_id,
  :extensions,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end