Class: Aws::IdentityStore::Types::ListUsersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-identitystore/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The pagination token used for the ‘ListUsers` and `ListGroups` API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
# File 'lib/aws-sdk-identitystore/types.rb', line 1419

class ListUsersResponse < Struct.new(
  :users,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#usersArray<Types::User>

A list of ‘User` objects in the identity store.

Returns:



1419
1420
1421
1422
1423
1424
# File 'lib/aws-sdk-identitystore/types.rb', line 1419

class ListUsersResponse < Struct.new(
  :users,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end