Class: Aws::IdentityStore::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-identitystore/types.rb

Overview

The request would cause the number of users or groups in the identity store to exceed the maximum allowed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String



1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-identitystore/types.rb', line 1637

class ServiceQuotaExceededException < Struct.new(
  :message,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The identifier for each request. This value is a globally unique ID that is generated by the identity store service for each sent request, and is then returned inside the exception if the request fails.



1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-identitystore/types.rb', line 1637

class ServiceQuotaExceededException < Struct.new(
  :message,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end