Class: Aws::IdentityStore::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IdentityStore::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-identitystore/types.rb
Overview
Indicates that the principal has crossed the throttling limits of the API operations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#reason ⇒ String
Indicates the reason for the throttling error when the service is unable to access a Customer Managed KMS key.
-
#request_id ⇒ String
The identifier for each request.
-
#retry_after_seconds ⇒ Integer
The number of seconds to wait before retrying the next request.
Instance Attribute Details
#message ⇒ String
1669 1670 1671 1672 1673 1674 1675 1676 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1669 class ThrottlingException < Struct.new( :message, :request_id, :retry_after_seconds, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
Indicates the reason for the throttling error when the service is unable to access a Customer Managed KMS key. For non-KMS permission errors, this field is not included.
1669 1670 1671 1672 1673 1674 1675 1676 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1669 class ThrottlingException < Struct.new( :message, :request_id, :retry_after_seconds, :reason) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The identifier for each request. This value is a globally unique ID that is generated by the identity store service for each sent request, and is then returned inside the exception if the request fails.
1669 1670 1671 1672 1673 1674 1675 1676 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1669 class ThrottlingException < Struct.new( :message, :request_id, :retry_after_seconds, :reason) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ Integer
The number of seconds to wait before retrying the next request.
1669 1670 1671 1672 1673 1674 1675 1676 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1669 class ThrottlingException < Struct.new( :message, :request_id, :retry_after_seconds, :reason) SENSITIVE = [] include Aws::Structure end |