Class: Aws::IdentityStore::Types::UpdateGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-identitystore/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#group_id ⇒ String

The identifier for a group in the identity store.

Returns:

  • (String)


1720
1721
1722
1723
1724
1725
1726
# File 'lib/aws-sdk-identitystore/types.rb', line 1720

class UpdateGroupRequest < Struct.new(
  :identity_store_id,
  :group_id,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end

#identity_store_id ⇒ String

The globally unique identifier for the identity store.

Returns:

  • (String)


1720
1721
1722
1723
1724
1725
1726
# File 'lib/aws-sdk-identitystore/types.rb', line 1720

class UpdateGroupRequest < Struct.new(
  :identity_store_id,
  :group_id,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end

#operations ⇒ Array<Types::AttributeOperation>

A list of AttributeOperation objects to apply to the requested group. These operations might add, replace, or remove an attribute. For more information on the attributes that can be added, replaced, or removed, see Group.

Returns:



1720
1721
1722
1723
1724
1725
1726
# File 'lib/aws-sdk-identitystore/types.rb', line 1720

class UpdateGroupRequest < Struct.new(
  :identity_store_id,
  :group_id,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end