Class: Aws::IdentityStore::Types::UpdateUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-identitystore/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identity_store_id ⇒ String

The globally unique identifier for the identity store.

Returns:

  • (String)


1753
1754
1755
1756
1757
1758
1759
# File 'lib/aws-sdk-identitystore/types.rb', line 1753

class UpdateUserRequest < Struct.new(
  :identity_store_id,
  :user_id,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end

#operations ⇒ Array<Types::AttributeOperation>

A list of AttributeOperation objects to apply to the requested user. These operations might add, replace, or remove an attribute. For more information on the attributes that can be added, replaced, or removed, see User.

Returns:



1753
1754
1755
1756
1757
1758
1759
# File 'lib/aws-sdk-identitystore/types.rb', line 1753

class UpdateUserRequest < Struct.new(
  :identity_store_id,
  :user_id,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end

#user_id ⇒ String

The identifier for a user in the identity store.

Returns:

  • (String)


1753
1754
1755
1756
1757
1758
1759
# File 'lib/aws-sdk-identitystore/types.rb', line 1753

class UpdateUserRequest < Struct.new(
  :identity_store_id,
  :user_id,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end