Class: Aws::IdentityStore::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IdentityStore::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-identitystore/client.rb
Overview
An API client for IdentityStore. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IdentityStore::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_group(params = {}) ⇒ Types::CreateGroupResponse
Creates a group within the specified identity store.
-
#create_group_membership(params = {}) ⇒ Types::CreateGroupMembershipResponse
Creates a relationship between a member and a group.
-
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user within the specified identity store.
-
#delete_group(params = {}) ⇒ Struct
Delete a group within an identity store given ‘GroupId`.
-
#delete_group_membership(params = {}) ⇒ Struct
Delete a membership within a group given ‘MembershipId`.
-
#delete_user(params = {}) ⇒ Struct
Deletes a user within an identity store given ‘UserId`.
-
#describe_group(params = {}) ⇒ Types::DescribeGroupResponse
Retrieves the group metadata and attributes from ‘GroupId` in an identity store.
-
#describe_group_membership(params = {}) ⇒ Types::DescribeGroupMembershipResponse
Retrieves membership metadata and attributes from ‘MembershipId` in an identity store.
-
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Retrieves the user metadata and attributes from the ‘UserId` in an identity store.
-
#get_group_id(params = {}) ⇒ Types::GetGroupIdResponse
Retrieves ‘GroupId` in an identity store.
-
#get_group_membership_id(params = {}) ⇒ Types::GetGroupMembershipIdResponse
Retrieves the ‘MembershipId` in an identity store.
-
#get_user_id(params = {}) ⇒ Types::GetUserIdResponse
Retrieves the ‘UserId` in an identity store.
-
#is_member_in_groups(params = {}) ⇒ Types::IsMemberInGroupsResponse
Checks the user’s membership in all requested groups and returns if the member exists in all queried groups.
-
#list_group_memberships(params = {}) ⇒ Types::ListGroupMembershipsResponse
For the specified group in the specified identity store, returns the list of all ‘ GroupMembership` objects and returns results in paginated form.
-
#list_group_memberships_for_member(params = {}) ⇒ Types::ListGroupMembershipsForMemberResponse
For the specified member in the specified identity store, returns the list of all ‘ GroupMembership` objects and returns results in paginated form.
-
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Lists all groups in the identity store.
-
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists all users in the identity store.
-
#update_group(params = {}) ⇒ Struct
Updates the specified group metadata and attributes in the specified identity store.
-
#update_user(params = {}) ⇒ Struct
Updates the specified user metadata and attributes in the specified identity store.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-identitystore/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1781 1782 1783 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1781 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1784 1785 1786 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1784 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1754 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IdentityStore') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-identitystore' context[:gem_version] = '1.70.0' Seahorse::Client::Request.new(handlers, context) end |
#create_group(params = {}) ⇒ Types::CreateGroupResponse
Creates a group within the specified identity store.
520 521 522 523 |
# File 'lib/aws-sdk-identitystore/client.rb', line 520 def create_group(params = {}, = {}) req = build_request(:create_group, params) req.send_request() end |
#create_group_membership(params = {}) ⇒ Types::CreateGroupMembershipResponse
Creates a relationship between a member and a group. The following identifiers must be specified: ‘GroupId`, `IdentityStoreId`, and `MemberId`.
564 565 566 567 |
# File 'lib/aws-sdk-identitystore/client.rb', line 564 def create_group_membership(params = {}, = {}) req = build_request(:create_group_membership, params) req.send_request() end |
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user within the specified identity store.
733 734 735 736 |
# File 'lib/aws-sdk-identitystore/client.rb', line 733 def create_user(params = {}, = {}) req = build_request(:create_user, params) req.send_request() end |
#delete_group(params = {}) ⇒ Struct
Delete a group within an identity store given ‘GroupId`.
759 760 761 762 |
# File 'lib/aws-sdk-identitystore/client.rb', line 759 def delete_group(params = {}, = {}) req = build_request(:delete_group, params) req.send_request() end |
#delete_group_membership(params = {}) ⇒ Struct
Delete a membership within a group given ‘MembershipId`.
785 786 787 788 |
# File 'lib/aws-sdk-identitystore/client.rb', line 785 def delete_group_membership(params = {}, = {}) req = build_request(:delete_group_membership, params) req.send_request() end |
#delete_user(params = {}) ⇒ Struct
Deletes a user within an identity store given ‘UserId`.
811 812 813 814 |
# File 'lib/aws-sdk-identitystore/client.rb', line 811 def delete_user(params = {}, = {}) req = build_request(:delete_user, params) req.send_request() end |
#describe_group(params = {}) ⇒ Types::DescribeGroupResponse
Retrieves the group metadata and attributes from ‘GroupId` in an identity store.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
877 878 879 880 |
# File 'lib/aws-sdk-identitystore/client.rb', line 877 def describe_group(params = {}, = {}) req = build_request(:describe_group, params) req.send_request() end |
#describe_group_membership(params = {}) ⇒ Types::DescribeGroupMembershipResponse
Retrieves membership metadata and attributes from ‘MembershipId` in an identity store.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
935 936 937 938 |
# File 'lib/aws-sdk-identitystore/client.rb', line 935 def describe_group_membership(params = {}, = {}) req = build_request(:describe_group_membership, params) req.send_request() end |
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Retrieves the user metadata and attributes from the ‘UserId` in an identity store.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
1068 1069 1070 1071 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1068 def describe_user(params = {}, = {}) req = build_request(:describe_user, params) req.send_request() end |
#get_group_id(params = {}) ⇒ Types::GetGroupIdResponse
Retrieves ‘GroupId` in an identity store.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
1126 1127 1128 1129 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1126 def get_group_id(params = {}, = {}) req = build_request(:get_group_id, params) req.send_request() end |
#get_group_membership_id(params = {}) ⇒ Types::GetGroupMembershipIdResponse
Retrieves the ‘MembershipId` in an identity store.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
1179 1180 1181 1182 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1179 def get_group_membership_id(params = {}, = {}) req = build_request(:get_group_membership_id, params) req.send_request() end |
#get_user_id(params = {}) ⇒ Types::GetUserIdResponse
Retrieves the ‘UserId` in an identity store.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
1237 1238 1239 1240 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1237 def get_user_id(params = {}, = {}) req = build_request(:get_user_id, params) req.send_request() end |
#is_member_in_groups(params = {}) ⇒ Types::IsMemberInGroupsResponse
Checks the user’s membership in all requested groups and returns if the member exists in all queried groups.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
1290 1291 1292 1293 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1290 def is_member_in_groups(params = {}, = {}) req = build_request(:is_member_in_groups, params) req.send_request() end |
#list_group_memberships(params = {}) ⇒ Types::ListGroupMembershipsResponse
For the specified group in the specified identity store, returns the list of all ‘ GroupMembership` objects and returns results in paginated form.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1362 1363 1364 1365 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1362 def list_group_memberships(params = {}, = {}) req = build_request(:list_group_memberships, params) req.send_request() end |
#list_group_memberships_for_member(params = {}) ⇒ Types::ListGroupMembershipsForMemberResponse
For the specified member in the specified identity store, returns the list of all ‘ GroupMembership` objects and returns results in paginated form.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1439 1440 1441 1442 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1439 def list_group_memberships_for_member(params = {}, = {}) req = build_request(:list_group_memberships_for_member, params) req.send_request() end |
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Lists all groups in the identity store. Returns a paginated list of complete ‘Group` objects. Filtering for a `Group` by the `DisplayName` attribute is deprecated. Instead, use the `GetGroupId` API action.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1524 1525 1526 1527 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1524 def list_groups(params = {}, = {}) req = build_request(:list_groups, params) req.send_request() end |
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists all users in the identity store. Returns a paginated list of complete ‘User` objects. Filtering for a `User` by the `UserName` attribute is deprecated. Instead, use the `GetUserId` API action.
<note markdown=“1”> If you have access to a member account, you can use this API operation from the member account. For more information, see [Limiting access to the identity store from member accounts] in the IAM Identity Center User Guide.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1659 1660 1661 1662 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1659 def list_users(params = {}, = {}) req = build_request(:list_users, params) req.send_request() end |
#update_group(params = {}) ⇒ Struct
Updates the specified group metadata and attributes in the specified identity store.
1702 1703 1704 1705 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1702 def update_group(params = {}, = {}) req = build_request(:update_group, params) req.send_request() end |
#update_user(params = {}) ⇒ Struct
Updates the specified user metadata and attributes in the specified identity store.
1745 1746 1747 1748 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1745 def update_user(params = {}, = {}) req = build_request(:update_user, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1774 1775 1776 |
# File 'lib/aws-sdk-identitystore/client.rb', line 1774 def waiter_names [] end |