Class: Aws::IdentityStore::Types::ListGroupMembershipsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IdentityStore::Types::ListGroupMembershipsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-identitystore/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_id ⇒ String
The identifier for a group in the identity store.
-
#identity_store_id ⇒ String
The globally unique identifier for the identity store.
-
#max_results ⇒ Integer
The maximum number of results to be returned per request.
-
#next_token ⇒ String
The pagination token used for the ‘ListUsers`, `ListGroups` and ` ListGroupMemberships` API operations.
Instance Attribute Details
#group_id ⇒ String
The identifier for a group in the identity store.
1268 1269 1270 1271 1272 1273 1274 1275 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1268 class ListGroupMembershipsRequest < Struct.new( :identity_store_id, :group_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#identity_store_id ⇒ String
The globally unique identifier for the identity store.
1268 1269 1270 1271 1272 1273 1274 1275 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1268 class ListGroupMembershipsRequest < Struct.new( :identity_store_id, :group_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to be returned per request. This parameter is used in all ‘ List` requests to specify how many results to return in one page.
1268 1269 1270 1271 1272 1273 1274 1275 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1268 class ListGroupMembershipsRequest < Struct.new( :identity_store_id, :group_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token used for the ‘ListUsers`, `ListGroups` and ` ListGroupMemberships` API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page.
1268 1269 1270 1271 1272 1273 1274 1275 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1268 class ListGroupMembershipsRequest < Struct.new( :identity_store_id, :group_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |