Class: Aws::IdentityStore::Types::ListGroupMembershipsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IdentityStore::Types::ListGroupMembershipsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-identitystore/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_memberships ⇒ Array<Types::GroupMembership>
A list of ‘GroupMembership` objects in the group.
-
#next_token ⇒ String
The pagination token used for the ‘ListUsers`, `ListGroups`, and ` ListGroupMemberships` API operations.
Instance Attribute Details
#group_memberships ⇒ Array<Types::GroupMembership>
A list of ‘GroupMembership` objects in the group.
1292 1293 1294 1295 1296 1297 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1292 class ListGroupMembershipsResponse < Struct.new( :group_memberships, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token used for the ‘ListUsers`, `ListGroups`, and ` ListGroupMemberships` API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page.
1292 1293 1294 1295 1296 1297 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1292 class ListGroupMembershipsResponse < Struct.new( :group_memberships, :next_token) SENSITIVE = [] include Aws::Structure end |