Class: Aws::IdentityStore::Types::ListGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IdentityStore::Types::ListGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-identitystore/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
A list of ‘Filter` objects, which is used in the `ListUsers` and ` ListGroups` requests.
-
#identity_store_id ⇒ String
The globally unique identifier for the identity store, such as ‘d-1234567890`.
-
#max_results ⇒ Integer
The maximum number of results to be returned per request.
-
#next_token ⇒ String
The pagination token used for the ‘ListUsers` and `ListGroups` API operations.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
A list of ‘Filter` objects, which is used in the `ListUsers` and ` ListGroups` requests.
1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1329 class ListGroupsRequest < Struct.new( :identity_store_id, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#identity_store_id ⇒ String
The globally unique identifier for the identity store, such as ‘d-1234567890`. In this example, `d-` is a fixed prefix, and `1234567890` is a randomly generated string that contains numbers and lower case letters. This value is generated at the time that a new identity store is created.
1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1329 class ListGroupsRequest < Struct.new( :identity_store_id, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to be returned per request. This parameter is used in the ‘ ListUsers` and `ListGroups` requests to specify how many results to return in one page. The length limit is 50 characters.
1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1329 class ListGroupsRequest < Struct.new( :identity_store_id, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token used for the ‘ListUsers` and `ListGroups` API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page.
1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1329 class ListGroupsRequest < Struct.new( :identity_store_id, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |