Class: Aws::IdentityStore::Types::ListUsersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IdentityStore::Types::ListUsersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-identitystore/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token used for the ‘ListUsers` and `ListGroups` API operations.
-
#users ⇒ Array<Types::User>
A list of ‘User` objects in the identity store.
Instance Attribute Details
#next_token ⇒ String
The pagination token used for the ‘ListUsers` and `ListGroups` API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page.
1419 1420 1421 1422 1423 1424 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1419 class ListUsersResponse < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::User>
A list of ‘User` objects in the identity store.
1419 1420 1421 1422 1423 1424 |
# File 'lib/aws-sdk-identitystore/types.rb', line 1419 class ListUsersResponse < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |